@@ -1,18 +1,18 @@
-#include <qapplication.h>
-#include <qtextedit.h>
-#include <qgroupbox.h>
-#include <qlineedit.h>
-#include <qlabel.h>
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qpushbutton.h>
-#include <qmessagebox.h>
-#include <qinputdialog.h>
-#include <qspinbox.h>
-#include <qtimer.h>
-#include <qmenubar.h>
-#include <qmenu.h>
-#include <qtabwidget.h>
+#include <QApplication>
+#include <QTextEdit>
+#include <QGroupBox>
+#include <QLineEdit>
+#include <QLabel>
+#include <QCheckBox>
+#include <QComboBox>
+#include <QPushButton>
+#include <QMessageBox>
+#include <QInputDialog>
+#include <QSpinBox>
+#include <QTimer>
+#include <QMenuBar>
+#include <QMenu>
+#include <QTabWidget>
 #include <QTextBlock>
 #include <qca.h>
 #include "xmpp.h"
